Module handler

Module handler 

Structs

Buffered
Marker type: when present in extensions, the body has been pre-buffered for interception.
Dropped
Marker type: when present in request extensions, the request was dropped by the interceptor.
LoggingHandler
Default handler that logs requests and responses without modification.

Traits

RequestHandler
Trait for intercepting and modifying HTTP requests and responses.

Functions

boxed_body
Convert an incoming body to our BoxBody type.
empty_boxed_body
Create an empty BoxBody.
extract_body_bytes
Extract body bytes from a request, replacing with empty body.
extract_response_body_bytes
Extract body bytes from a response, replacing with empty body.
full_boxed_body
Create a BoxBody from Bytes (fully buffered).
put_body_back
Put bytes back as the request body.
put_response_body_back
Put bytes back as the response body.

Type Aliases

BoxBody