Module logging

Module logging 

Structs

LogEntry
LogId
Unique ID for pairing request and response in the log.
LoggedRequest
LoggedResponse
TrafficLogHandler
Decorator handler that logs traffic to a JSON Lines file. Wraps any inner RequestHandler.
UpstreamTarget
Upstream target info stored in request extensions for logging.