Structs
- Buffered
- Marker type: when present in extensions, the body has been pre-buffered for interception.
- Dropped
- Marker type: when present in request extensions, the request was dropped by the interceptor.
- Logging
Handler - Default handler that logs requests and responses without modification.
Traits
- Request
Handler - Trait for intercepting and modifying HTTP requests and responses.
Functions
- boxed_
body - Convert an incoming body to our BoxBody type.
- empty_
boxed_ body - Create an empty BoxBody.
- extract_
body_ bytes - Extract body bytes from a request, replacing with empty body.
- extract_
response_ body_ bytes - Extract body bytes from a response, replacing with empty body.
- full_
boxed_ body - Create a BoxBody from Bytes (fully buffered).
- put_
body_ back - Put bytes back as the request body.
- put_
response_ body_ back - Put bytes back as the response body.